===============================
:code:`Trakt['sync/watchlist']`
===============================

.. automodule:: trakt.interfaces.sync.watchlist

  .. autoclass:: SyncWatchlistInterface
    :members: add, episodes, flags, get, movies, remove, seasons, shows
    :undoc-members:
